import React, { useContext } from 'react';
import { Container, Box } from "../Layout";
import Label from "../Label/Label";
import style from "./SwitchNew.module.css";
import { defaultProps } from "./props/defaultProps";
import { propTypes } from "./props/propTypes";
import LibraryContext from "../Provider/LibraryContextInit";

const SwitchNew = props => {
  const {
    id,
    title,
    name,
    value,
    checked,
    disabled,
    isReadOnly,
    size,
    text,
    disableTitle,
    dataId,
    dataSelectorId,
    onChange,
    customProps,
    customClass,
    labelSize,
    labelPlacement,
    a11y
  } = props;

  const handleChange = e => {
    if (!disabled && !isReadOnly && onChange) {
      onChange(!checked, e);
    }
  };

  const {
    SwitchProps = {},
    LabelProps = {}
  } = customProps || {};
  const {
    WrapperProps = {},
    TrackProps = {}
  } = SwitchProps;
  const {
    customSwitchWrap = '',
    customSwitch = '',
    customLabel = ''
  } = customClass || {};
  const {
    role = 'switch',
    ...a11yAttributes
  } = a11y || {};
  const context = useContext(LibraryContext);
  const {
    a11y_onOffLabel = true
  } = context;
  return /*#__PURE__*/React.createElement(Container, {
    align: "vertical",
    isCover: false,
    isInline: true,
    alignBox: labelPlacement == 'right' ? 'row' : 'row-reverse',
    "data-title": disabled ? disableTitle : title,
    dataSelectorId: dataSelectorId,
    className: customSwitchWrap ? customSwitchWrap : '',
    ...WrapperProps
  }, /*#__PURE__*/React.createElement("div", {
    className: `${style.switchWrapper} ${style[`${size}_switch`]} ${!disabled && !isReadOnly ? style.effect : ''} ${disabled ? style.disabled : ''}`
  }, /*#__PURE__*/React.createElement("input", {
    type: "checkbox",
    id: id,
    name: name,
    value: value,
    checked: checked,
    disabled: disabled,
    readOnly: isReadOnly,
    onChange: handleChange,
    role: role,
    "aria-checked": checked,
    tabIndex: disabled ? -1 : 0,
    "data-id": dataId,
    "data-test-id": dataId,
    className: `${style.track} ${customSwitch} ${a11y_onOffLabel ? checked ? style.onLabel : style.offLabel : ''}`,
    ...a11yAttributes,
    ...TrackProps
  }), /*#__PURE__*/React.createElement("span", {
    className: style.thumb
  }), a11y_onOffLabel ? /*#__PURE__*/React.createElement("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: `0 0 ${checked ? '2' : 'var(--switch-off-label-size)'} ${checked ? 'var(--switch-on-label-height)' : 'var(--switch-off-label-size)'}`,
    className: `${checked ? style[`${size}OnLabelWrapper`] : style[`${size}OffLabelWrapper`]} ${style.labelWrapper}`
  }, checked ? /*#__PURE__*/React.createElement("rect", {
    x: "0",
    rx: "0.8",
    ry: "0.8",
    width: "100%",
    height: "100%",
    className: style.onLabel
  }) : /*#__PURE__*/React.createElement("circle", {
    className: style.offLabel,
    cx: "50%",
    cy: "50%",
    width: "100%",
    height: "100%",
    fill: "none"
  })) : null), text && /*#__PURE__*/React.createElement(Label, {
    customClass: ` ${style[`switchLabel_${labelPlacement}`]}  ${customLabel ? customLabel : ''}`,
    htmlFor: id,
    size: labelSize,
    type: "subtitle",
    text: text,
    ...LabelProps
  }));
};

export default SwitchNew;
SwitchNew.defaultProps = defaultProps;
SwitchNew.propTypes = propTypes;